==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Emmagatzematge temporalment no disponible",
    "Storage invalid" : "Emmagatzematge no vàlid",
    "Unknown error" : "Error desconegut",
    "All files" : "Tots els fitxers",
    "Recent" : "Recents",
    "Favorites" : "Preferits",
    "File could not be found" : "No s'ha pogut trobar el fitxer",
    "Move or copy" : "Mou o copia",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "Home" : "Inici",
    "Close" : "Tanca",
    "Could not create folder \"{dir}\"" : "No s'ha pogut crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Això aturarà les càrregues actuals.",
    "Upload cancelled." : "S'ha cancel·lat la càrrega.",
    "Processing files …" : "S'estan processant fitxers …",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot carregar {filename} perquè és un directori o té 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, esteu carregant {size1} però només en queda {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta objectiu \"{dir}\" ja no existeix",
    "Not enough free space" : "Espai lliure insuficient",
    "An unknown error has occurred" : "S'ha produït un error desconegut",
    "Uploading …" : "S'està carregant...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "La càrrega d'aquest element no està suportada",
    "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
    "Error when assembling chunks, status code {status}" : "S'ha produït un error mentre es recopilaven els fragments, el codi d'estat és {status}",
    "Actions" : "Accions",
    "Rename" : "Canvia el nom",
    "Copy" : "Copia",
    "Choose target folder" : "Tria la carpeta de destinació",
    "Open" : "Obre",
    "Delete file" : "Suprimeix el fitxer",
    "Delete folder" : "Suprimeix la carpeta",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer \"{file}\"",
    "Files" : "Fitxers",
    "Details" : "Detalls",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "This operation is forbidden" : "Aquesta operació està prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Aquest directori no està disponible. Comproveu els registres o contacteu amb l'administrador.",
    "Could not move \"{file}\", target exists" : "No s'ha pugut moure \"{file}\", el fitxer destinació ja existeix",
    "Could not move \"{file}\"" : "No s'ha pogut moure \"{file}\"",
    "copy" : "còpia",
    "Could not copy \"{file}\", target exists" : "No s'ha pogut copiar \"{file}\", el fitxer destinació ja existeix",
    "Could not copy \"{file}\"" : "No s'ha pogut copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiat {origen} dins de {destinació}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "S'ha copiat {origen} i {nbfiles} altres fitxers a dins de {destinació}",
    "{newName} already exists" : "{newName} ja existeix",
    "Could not rename \"{fileName}\", it does not exist any more" : "No s'ha pogut reanomenar \"{fileName}\", ja no existeix",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom \"{targetName}\" ja s'utilitza a la carpeta \"{dir}\". Trieu un nom diferent.",
    "Could not rename \"{fileName}\"" : "No s'ha pogut reanomenar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No s'ha pogut crear el fitxer \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No s'ha pogut crear el fitxer \"{file}\" perquè ja existeix",
    "Could not create folder \"{dir}\" because it already exists" : "No s'ha pogut crear la carpeta \"{dir}\" perquè ja existeix",
    "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca a altres carpetes per {tag} {filter} {end tag}",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Darrera modificació",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["incloent %n ocult","incloent %n ocults"],
    "You don’t have permission to upload or create files here" : "No teniu permís per pujar o crear fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
    "New" : "Nou",
    "Select file range" : "Selecciona el rang de fitxers",
    "{used} of {quota} used" : "{used} de {quota} utilitzat",
    "{used} used" : "{used} utilitzat",
    "\"{name}\" is an invalid file name." : "\"{name}\" no és un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "\"/\" is not allowed inside a file name." : "El caràcter \"/\" no es pot utilitzar en el nom del fitxer.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no és un tipus de fitxer permès",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzematge és ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} és gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzematge és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "View in folder" : "Mostra-ho a la carpeta",
    "Copied!" : "Copiat!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona pels usuaris que tenen accés a aquest fitxer/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "S'ha afegit als preferits",
    "Favorite" : "Preferits",
    "You can only favorite a single file or folder at a time" : "Només podeu afegir a preferits un únic fitxer o carpeta alhora",
    "New folder" : "Crea una carpeta",
    "Upload file" : "Puja un fitxer",
    "Not favorited" : "No està inclòs en els favorits",
    "Remove from favorites" : "Suprimeix dels favorits",
    "Add to favorites" : "Afegeix als preferits",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "Added to favorites" : "Afegit a favorits",
    "Removed from favorites" : "Suprimeix de preferits",
    "You added {file} to your favorites" : "Heu afegit {file} als vostres preferits",
    "You removed {file} from your favorites" : "Heu suprimit {file} dels vostres preferits",
    "File changes" : "Canvis al fitxer",
    "Created by {user}" : "Creat per {user}",
    "Changed by {user}" : "Canviat per {user}",
    "Deleted by {user}" : "Suprimit per {user}",
    "Restored by {user}" : "Restaurat per {user}",
    "Renamed by {user}" : "Renomenat per {user}",
    "Moved by {user}" : "Mogut per {user}",
    "\"remote user\"" : "\"usuari remot\"",
    "You created {file}" : "Heu creat {file}",
    "You created an encrypted file in {file}" : "Heu creat un fitxer xifrat a {file}",
    "{user} created {file}" : "{user} ha creat {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creat un fitxer xifrat a {file}",
    "{file} was created in a public folder" : "S'ha creat {file} a una carpeta pública",
    "You changed {file}" : "Heu modificat {file}",
    "You changed an encrypted file in {file}" : "Heu canviat un fitxer xifrat a {file}",
    "{user} changed {file}" : "{user} ha modificat {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha canviat un fitxer xifrat a {file}",
    "You deleted {file}" : "Heu suprimit {file}",
    "You deleted an encrypted file in {file}" : "Heu suprimit un fitxer xifrat a {file}",
    "{user} deleted {file}" : "{user} ha suprimit {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha suprimit un fitxer xifrat a {file}",
    "You restored {file}" : "Heu restaurat {file}",
    "{user} restored {file}" : "{user} ha restaurat {file}",
    "You renamed {oldfile} to {newfile}" : "Heu canviat el nom de {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha ha canviat el nom de {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Heu mogut {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha mogut {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "S'ha afegit o suprimit un fitxer del vostres <strong>favorits</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fitxer o carpeta ha estat  <strong>canviat</strong> o <strong>renomenat</strong>",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>suprimit</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita les notificacions sobre la creació i canvis dels vostres <strong>fitxers favorits</strong><em>(només Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "Unlimited" : "Il·limitat",
    "Upload (max. %s)" : "Càrrega (màx. %s)",
    "File Management" : "Gestió de fitxers",
    "%s used" : "%s utilitzat",
    "%s%% of %s used" : "Usat%s%% de %s ",
    "%1$s of %2$s used" : "%1$s de %2$s utilitzat",
    "Settings" : "Paràmetres",
    "Show hidden files" : "Mostra els fitxers ocults",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilitzeu aquesta adreça per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accedir als vostres fitxers mitjançant WebDAV</a>",
    "Toggle grid view" : "Commuta vista de quadrícula",
    "No files in here" : "No hi ha fitxers aquí",
    "Upload some content or sync with your devices!" : "Carregeu continguts o sincronitzeu els vostres dispositius!",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Selecciona-ho tot",
    "Upload too large" : "La càrrega és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant carregar excedeixen la mida màxima de càrrega del servidor",
    "No favorites yet" : "No hi ha preferits encara",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els fitxers i carpetes que marqueu com a favorits",
    "Tags" : "Etiquetes",
    "Deleted files" : "Fitxers suprimits",
    "Shares" : "Comparticions",
    "Shared with others" : "Compartit amb altres",
    "Shared with you" : "Compartit amb tu",
    "Shared by link" : "Compartit per un enllaç",
    "Deleted shares" : "Comparticions suprimides",
    "Text file" : "Fitxer de text",
    "New text file.txt" : "Nou fitxer de text text.txt",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de càrrega",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Amb PHP-FPM pot trigar 5 minuts a aplicar els canvis.",
    "Missing permissions to edit from here." : "Falta els permisos per editar des d'aquí.",
    "Cancel upload" : "Cancel·la la càrrega",
    "%s of %s used" : "Utilitzats %s de %s",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s utilitzat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Emmagatzematge temporalment no disponible",
    "Storage invalid" : "Emmagatzematge no vàlid",
    "Unknown error" : "Error desconegut",
    "All files" : "Tots els fitxers",
    "Recent" : "Recents",
    "Favorites" : "Preferits",
    "File could not be found" : "No s'ha pogut trobar el fitxer",
    "Move or copy" : "Mou o copia",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "Home" : "Inici",
    "Close" : "Tanca",
    "Could not create folder \"{dir}\"" : "No s'ha pogut crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Això aturarà les càrregues actuals.",
    "Upload cancelled." : "S'ha cancel·lat la càrrega.",
    "Processing files …" : "S'estan processant fitxers …",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot carregar {filename} perquè és un directori o té 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, esteu carregant {size1} però només en queda {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta objectiu \"{dir}\" ja no existeix",
    "Not enough free space" : "Espai lliure insuficient",
    "An unknown error has occurred" : "S'ha produït un error desconegut",
    "Uploading …" : "S'està carregant...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "La càrrega d'aquest element no està suportada",
    "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
    "Error when assembling chunks, status code {status}" : "S'ha produït un error mentre es recopilaven els fragments, el codi d'estat és {status}",
    "Actions" : "Accions",
    "Rename" : "Canvia el nom",
    "Copy" : "Copia",
    "Choose target folder" : "Tria la carpeta de destinació",
    "Open" : "Obre",
    "Delete file" : "Suprimeix el fitxer",
    "Delete folder" : "Suprimeix la carpeta",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer \"{file}\"",
    "Files" : "Fitxers",
    "Details" : "Detalls",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "This operation is forbidden" : "Aquesta operació està prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Aquest directori no està disponible. Comproveu els registres o contacteu amb l'administrador.",
    "Could not move \"{file}\", target exists" : "No s'ha pugut moure \"{file}\", el fitxer destinació ja existeix",
    "Could not move \"{file}\"" : "No s'ha pogut moure \"{file}\"",
    "copy" : "còpia",
    "Could not copy \"{file}\", target exists" : "No s'ha pogut copiar \"{file}\", el fitxer destinació ja existeix",
    "Could not copy \"{file}\"" : "No s'ha pogut copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiat {origen} dins de {destinació}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "S'ha copiat {origen} i {nbfiles} altres fitxers a dins de {destinació}",
    "{newName} already exists" : "{newName} ja existeix",
    "Could not rename \"{fileName}\", it does not exist any more" : "No s'ha pogut reanomenar \"{fileName}\", ja no existeix",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom \"{targetName}\" ja s'utilitza a la carpeta \"{dir}\". Trieu un nom diferent.",
    "Could not rename \"{fileName}\"" : "No s'ha pogut reanomenar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No s'ha pogut crear el fitxer \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No s'ha pogut crear el fitxer \"{file}\" perquè ja existeix",
    "Could not create folder \"{dir}\" because it already exists" : "No s'ha pogut crear la carpeta \"{dir}\" perquè ja existeix",
    "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca a altres carpetes per {tag} {filter} {end tag}",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Darrera modificació",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["incloent %n ocult","incloent %n ocults"],
    "You don’t have permission to upload or create files here" : "No teniu permís per pujar o crear fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
    "New" : "Nou",
    "Select file range" : "Selecciona el rang de fitxers",
    "{used} of {quota} used" : "{used} de {quota} utilitzat",
    "{used} used" : "{used} utilitzat",
    "\"{name}\" is an invalid file name." : "\"{name}\" no és un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "\"/\" is not allowed inside a file name." : "El caràcter \"/\" no es pot utilitzar en el nom del fitxer.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no és un tipus de fitxer permès",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzematge és ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} és gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzematge és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "View in folder" : "Mostra-ho a la carpeta",
    "Copied!" : "Copiat!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona pels usuaris que tenen accés a aquest fitxer/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "S'ha afegit als preferits",
    "Favorite" : "Preferits",
    "You can only favorite a single file or folder at a time" : "Només podeu afegir a preferits un únic fitxer o carpeta alhora",
    "New folder" : "Crea una carpeta",
    "Upload file" : "Puja un fitxer",
    "Not favorited" : "No està inclòs en els favorits",
    "Remove from favorites" : "Suprimeix dels favorits",
    "Add to favorites" : "Afegeix als preferits",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "Added to favorites" : "Afegit a favorits",
    "Removed from favorites" : "Suprimeix de preferits",
    "You added {file} to your favorites" : "Heu afegit {file} als vostres preferits",
    "You removed {file} from your favorites" : "Heu suprimit {file} dels vostres preferits",
    "File changes" : "Canvis al fitxer",
    "Created by {user}" : "Creat per {user}",
    "Changed by {user}" : "Canviat per {user}",
    "Deleted by {user}" : "Suprimit per {user}",
    "Restored by {user}" : "Restaurat per {user}",
    "Renamed by {user}" : "Renomenat per {user}",
    "Moved by {user}" : "Mogut per {user}",
    "\"remote user\"" : "\"usuari remot\"",
    "You created {file}" : "Heu creat {file}",
    "You created an encrypted file in {file}" : "Heu creat un fitxer xifrat a {file}",
    "{user} created {file}" : "{user} ha creat {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creat un fitxer xifrat a {file}",
    "{file} was created in a public folder" : "S'ha creat {file} a una carpeta pública",
    "You changed {file}" : "Heu modificat {file}",
    "You changed an encrypted file in {file}" : "Heu canviat un fitxer xifrat a {file}",
    "{user} changed {file}" : "{user} ha modificat {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha canviat un fitxer xifrat a {file}",
    "You deleted {file}" : "Heu suprimit {file}",
    "You deleted an encrypted file in {file}" : "Heu suprimit un fitxer xifrat a {file}",
    "{user} deleted {file}" : "{user} ha suprimit {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha suprimit un fitxer xifrat a {file}",
    "You restored {file}" : "Heu restaurat {file}",
    "{user} restored {file}" : "{user} ha restaurat {file}",
    "You renamed {oldfile} to {newfile}" : "Heu canviat el nom de {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha ha canviat el nom de {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Heu mogut {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha mogut {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "S'ha afegit o suprimit un fitxer del vostres <strong>favorits</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fitxer o carpeta ha estat  <strong>canviat</strong> o <strong>renomenat</strong>",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>suprimit</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita les notificacions sobre la creació i canvis dels vostres <strong>fitxers favorits</strong><em>(només Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "Unlimited" : "Il·limitat",
    "Upload (max. %s)" : "Càrrega (màx. %s)",
    "File Management" : "Gestió de fitxers",
    "Error while loading the file data" : "S'ha produït un error mentre es carregava la informació de l'arxiu",
    "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de favorit de l'arxiu",
    "%s used" : "%s utilitzat",
    "%s%% of %s used" : "Usat%s%% de %s ",
    "%1$s of %2$s used" : "%1$s de %2$s utilitzat",
    "Settings" : "Paràmetres",
    "Show hidden files" : "Mostra els fitxers ocults",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilitzeu aquesta adreça per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accedir als vostres fitxers mitjançant WebDAV</a>",
    "Toggle grid view" : "Commuta vista de quadrícula",
    "No files in here" : "No hi ha fitxers aquí",
    "Upload some content or sync with your devices!" : "Carregeu continguts o sincronitzeu els vostres dispositius!",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Selecciona-ho tot",
    "Upload too large" : "La càrrega és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant carregar excedeixen la mida màxima de càrrega del servidor",
    "No favorites yet" : "No hi ha preferits encara",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els fitxers i carpetes que marqueu com a favorits",
    "Tags" : "Etiquetes",
    "Deleted files" : "Fitxers suprimits",
    "Shares" : "Comparticions",
    "Shared with others" : "Compartit amb altres",
    "Shared with you" : "Compartit amb tu",
    "Shared by link" : "Compartit per un enllaç",
    "Deleted shares" : "Comparticions suprimides",
    "Text file" : "Fitxer de text",
    "New text file.txt" : "Nou fitxer de text text.txt",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de càrrega",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Amb PHP-FPM pot trigar 5 minuts a aplicar els canvis.",
    "Missing permissions to edit from here." : "Falta els permisos per editar des d'aquí.",
    "Cancel upload" : "Cancel·la la càrrega",
    "%s of %s used" : "Utilitzats %s de %s",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s utilitzat"
},
"nplurals=2; plural=(n != 1);");
